@@ -5,21 +5,21 @@ use warnings;
 use Test::Classy::Base;
 use Log::Dump::Test::Class;
 
-sub class_has : Tests(4) {
+sub class_has : Tests(5) {
   my $class = shift;
 
-  foreach my $method (qw( log logger logfilter logfile )) {
+  foreach my $method (qw( log logger logfilter logfile logcolor )) {
     ok(Log::Dump::Test::Class->can($method),
        $class->message($method));
   }
 }
 
-sub object_has : Tests(4) {
+sub object_has : Tests(5) {
   my $class = shift;
 
   my $object = Log::Dump::Test::Class->new;
 
-  foreach my $method (qw( log logger logfilter logfile )) {
+  foreach my $method (qw( log logger logfilter logfile logcolor )) {
     ok($object->can($method),
        $class->message($method));
   }
